# -*- coding: utf-8 -*-
"""ConfusionMatrix, Compare and CI errors."""


class pycmVectorError(Exception):
    """Vector error class."""

    pass


class pycmMatrixError(Exception):
    """Matrix error class."""

    pass


class pycmCIError(Exception):
    """CI error class."""

    pass


class pycmAverageError(Exception):
    """Average error class."""

    pass


class pycmCompareError(Exception):
    """Compare error class."""

    pass


class pycmPlotError(Exception):
    """Plot error class."""

    pass


class pycmCurveError(Exception):
    """Curve error class."""

    pass
